@@ -64,113 +64,6 @@ checkVariableInX <- function(indexDate, x, nullOk = FALSE, name = "indexDate") {
   invisible(NULL)
 }
 
-#' @noRd
-checkAgeGroup <- function(ageGroup, overlap = FALSE) {
-  omopgenerics::assertList(ageGroup, null = TRUE)
-  if (!is.null(ageGroup)) {
-    if (is.numeric(ageGroup[[1]])) {
-      ageGroup <- list("age_group" = ageGroup)
-    }
-    for (k in seq_along(ageGroup)) {
-      invisible(checkCategory(ageGroup[[k]], overlap))
-      if (any(ageGroup[[k]] |> unlist() |> unique() < 0)) {
-        cli::cli_abort("ageGroup can't contain negative values")
-      }
-    }
-    if (is.null(names(ageGroup))) {
-      names(ageGroup) <- paste0("age_group_", 1:length(ageGroup))
-    }
-    if ("" %in% names(ageGroup)) {
-      id <- which(names(ageGroup) == "")
-      names(ageGroup)[id] <- paste0("age_group_", id)
-    }
-  }
-  invisible(ageGroup)
-}
-
-#' @noRd
-checkWindow <- function(window, call = parent.frame()) {
-  if (!is.list(window)) {
-    cli::cli_abort("window must be a list", call = call)
-  }
-
-  # Find if any NA, throw warning that it will be changed to Inf, change it later
-  if (any(unlist(lapply(window, is.na)))) {
-    cli::cli_abort("NA found in window, please use Inf or -Inf instead", call = call)
-  }
-
-  originalWindow <- window
-  # change inf to NA to check for floats, as Inf won't pass integerish check
-  window <- lapply(window, function(x) replace(x, is.infinite(x), NA))
-  omopgenerics::assertList(window, class = "numeric", call = call)
-  omopgenerics::assertNumeric(window |> unlist(), integerish = TRUE, na = TRUE, call = call)
-  window <- originalWindow
-
-  # if any element of window list has length over 2, throw error
-  if (any(lengths(window) > 2)) {
-    cli::cli_abort("window can only contain two values: windowStart and windowEnd", call = call)
-  }
-
-  # eg if list(1,2,3), change to list(c(1,1), c(2,2), c(3,3))
-  if (length(window) > 1 && any(lengths(window) == 1)) {
-    window[lengths(window) == 1] <- lapply(
-      window[lengths(window) == 1],
-      function(x) c(unlist(x[lengths(x) == 1]), unlist(x[lengths(x) == 1]))
-    )
-    cli::cli_warn("Window list contains element with only 1 value provided,
-          use it as both window start and window end")
-  }
-
-  names(window) <- getWindowNames(window)
-  lower <- lapply(window, function(x) {
-    x[1]
-  }) %>% unlist()
-  upper <- lapply(window, function(x) {
-    x[2]
-  }) %>% unlist()
-
-  if (any(lower > upper)) {
-    cli::cli_abort("First element in window must be smaller or equal to the second one", call = call)
-  }
-  if (any(is.infinite(lower) & lower == upper & sign(upper) == 1)) {
-    cli::cli_abort("Not both elements in the window can be +Inf", call = call)
-  }
-  if (any(is.infinite(lower) & lower == upper & sign(upper) == -1)) {
-    cli::cli_abort("Not both elements in the window can be -Inf", call = call)
-  }
-
-  invisible(window)
-}
-
-#' @noRd
-checkNewName <- function(name, x) {
-  renamed <- name[name %in% colnames(x)]
-  if (length(renamed) > 0) {
-    mes <- paste0(
-      "The following columns will be overwritten: ",
-      paste0(renamed, collapse = ", ")
-    )
-    cli::cli_warn(message = mes)
-  }
-  invisible(name)
-}
-
-#' @noRd
-getWindowNames <- function(window) {
-  getname <- function(element) {
-    element <- tolower(as.character(element))
-    element <- gsub("-", "m", element)
-    invisible(paste0(element[1], "_to_", element[2]))
-  }
-  windowNames <- names(window)
-  if (is.null(windowNames)) {
-    windowNames <- lapply(window, getname)
-  } else {
-    windowNames[windowNames == ""] <- lapply(window[windowNames == ""], getname)
-  }
-  invisible(windowNames)
-}
-
 #' @noRd
 checkFilter <- function(filterVariable, filterId, idName, x) {
   if (is.null(filterVariable)) {
@@ -557,46 +450,6 @@ validateAgeMissingDay <- function(ageMissingDay, null, call) {
 
   return(ageMissingDay)
 }
-validateAgeGroup <- function(ageGroup, call) {
-  if (length(ageGroup) == 0) {
-    return(NULL)
-  }
-  omopgenerics::assertList(ageGroup, call = call)
-  if (is.numeric(ageGroup[[1]])) {
-    ageGroup <- list("age_group" = ageGroup)
-  }
-  for (k in seq_along(ageGroup)) {
-    invisible(checkCategory(ageGroup[[k]], call = call))
-    if (any(ageGroup[[k]] |> unlist() |> unique() < 0)) {
-      cli::cli_abort("ageGroup can't contain negative values", call = call)
-    }
-    if (is.null(names(ageGroup[[k]]))) {
-      nms <- rep("", length(ageGroup[[k]]))
-    } else {
-      nms <- names(ageGroup[[k]])
-    }
-    for (i in seq_along(nms)) {
-      if (nms[i] == "") {
-        if (is.infinite(ageGroup[[k]][[i]][2])) {
-          nms[i] <- paste(round(ageGroup[[k]][[i]][1]), "or above")
-        } else {
-          nms[i] <- paste(
-            round(ageGroup[[k]][[i]][1]), "to", round(ageGroup[[k]][[i]][2])
-          )
-        }
-      }
-    }
-    names(ageGroup[[k]]) <- nms
-  }
-  if (is.null(names(ageGroup))) {
-    names(ageGroup) <- paste0("age_group_", 1:length(ageGroup))
-  }
-  if ("" %in% names(ageGroup)) {
-    id <- which(names(ageGroup) == "")
-    names(ageGroup)[id] <- paste0("age_group_", id)
-  }
-  invisible(ageGroup)
-}
 validateMissingValue <- function(x, null, call) {
   if (null) {
     return(NULL)
