@@ -172,10 +172,16 @@ test_that("query gives same result as main function", {
   # we should get the same results if compute was internal or not
   result_1 <- cdm$cohort1 %>%
     addInObservation() %>%
-    dplyr::collect()
+    dplyr::collect() |>
+    dplyr::arrange(cohort_definition_id,
+                   subject_id,
+                   cohort_start_date)
   result_2 <- cdm$cohort1 %>%
     addInObservationQuery() |>
-    dplyr::collect()
+    dplyr::collect() |>
+    dplyr::arrange(cohort_definition_id,
+                   subject_id,
+                   cohort_start_date)
   expect_equal(result_1, result_2)
 
   # check no tables are created along the way with query
