@@ -1,4 +1,5 @@
 test_that("test variableTypes", {
+  skip_on_cran()
   expect_no_error(x <- variableTypes(dplyr::tibble()))
   expect_identical(
     x,
@@ -85,6 +86,7 @@ test_that("test variableTypes", {
 })
 
 test_that("test functions", {
+  skip_on_cran()
   expect_true("tbl" %in% class(availableEstimates("numeric")))
   expect_true("tbl" %in% class(availableEstimates("date")))
   expect_true("tbl" %in% class(availableEstimates("categorical")))
@@ -95,6 +97,7 @@ test_that("test functions", {
 })
 
 test_that("test available functions", {
+  skip_on_cran()
   num_test <- availableEstimates("numeric")
   expect_true(all(
     c("sd", "median", "mean") %in% (
@@ -104,6 +107,7 @@ test_that("test available functions", {
 })
 
 test_that("binaryVariable test", {
+  skip_on_cran()
   expect_false(
     binaryVariable(c("A", "B", "C"))
   )
@@ -132,134 +136,11 @@ test_that("binaryVariable test", {
 })
 
 test_that("getFunction tests", {
-  x <- dplyr::tibble(
-    id = c(rep(1, 50), rep(2, 50)),
-    cov = c(1:100)
-  )
-
-  expect_warning(
-    y <- x %>%
-      dplyr::summarise(
-        dplyr::across(
-          .fns = !!getFunctions(c(
-            "min",
-            "max",
-            "sum",
-            "mean",
-            "median"
-          ))
-        ),
-        .groups = "drop"
-      )
-  )
-
-  expect_identical(
-    y %>% dplyr::pull("cov_min") %>% as.numeric(),
-    1
-  )
-
-  expect_identical(
-    y %>% dplyr::pull("cov_sum") %>% as.numeric(),
-    5050
-  )
-
-  expect_identical(
-    y %>% dplyr::pull("cov_mean") %>% as.numeric(),
-    50.5
-  )
-
-  expect_identical(
-    y %>% dplyr::pull("cov_median") %>% as.numeric(),
-    50.5
-  )
-
-  expect_identical(
-    y %>% dplyr::pull("cov_max") %>% as.numeric(),
-    100
-  )
-})
-
-test_that("getFunction tests; quantiles q01- q09", {
-  x <- dplyr::tibble(
-    cov = c(1:100)
-  )
-
-  est <- c()
-  for (i in (1:9)) {
-    est <- c(est, paste0("q0", i))
-  }
-
-  expect_warning(y <- x %>%
-    dplyr::summarise(
-      dplyr::across(
-        .fns = !!getFunctions(est)
-      ),
-      .groups = "drop"
-    ))
-
-  for (i in (1:(length(est) - 1))) {
-    expect_true(
-      (y %>%
-        dplyr::pull(paste0("cov_", est[[i]]))) <=
-        (y %>% dplyr::pull(paste0("cov_", est[[i + 1]])))
-    )
-  }
-})
-
-test_that("getFunction tests; quantiles q10- q49", {
-  x <- dplyr::tibble(
-    cov = c(1:100)
-  )
-
-  est <- c()
-  for (i in (10:49)) {
-    est <- c(est, paste0("q", i))
-  }
-
-  expect_warning(
-    y <- x %>%
-      dplyr::summarise(
-        dplyr::across(
-          .fns = !!getFunctions(est)
-        ),
-        .groups = "drop"
-      )
-  )
-
-  for (i in (1:(length(est) - 1))) {
-    expect_true(
-      (y %>%
-        dplyr::pull(paste0("cov_", est[[i]]))) <=
-        (y %>% dplyr::pull(paste0("cov_", est[[i + 1]])))
-    )
-  }
-})
-
-test_that("getFunction tests; quantiles q51 - q99", {
-  x <- dplyr::tibble(
-    cov = c(1:100)
-  )
-
-  est <- c()
-  for (i in (51:99)) {
-    est <- c(est, paste0("q", i))
-  }
-
-  expect_warning(
-    y <- x %>%
-      dplyr::summarise(
-        dplyr::across(
-          .fns = !!getFunctions(est)
-        ),
-        .groups = "drop"
-      )
-  )
-
-  for (i in (1:(length(est) - 1))) {
-    expect_true(
-      (y %>%
-        dplyr::pull(paste0("cov_", est[[i]]))) <=
-        (y %>% dplyr::pull(paste0("cov_", est[[i + 1]])))
-    )
-  }
+  skip_on_cran()
+  expect_true(estimatesFunc["min"] == "base::min(x, na.rm = TRUE)")
+  expect_true(estimatesFunc["max"] == "base::max(x, na.rm = TRUE)")
+  expect_true(estimatesFunc["mean"] == "base::mean(x, na.rm = TRUE)")
+  expect_true(estimatesFunc["sd"] == "stats::sd(x, na.rm = TRUE)")
+  expect_true(estimatesFunc["q99"] == "stats::quantile(x, 0.99, na.rm = TRUE)")
+  expect_true(estimatesFunc["q09"] == "stats::quantile(x, 0.09, na.rm = TRUE)")
 })
